You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by hn...@apache.org on 2022/10/05 09:25:22 UTC

[myfaces-tobago] branch main updated: feat: rename to jakarta namespace

This is an automated email from the ASF dual-hosted git repository.

hnoeth pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/myfaces-tobago.git


The following commit(s) were added to refs/heads/main by this push:
     new 24d7027c7c feat: rename to jakarta namespace
24d7027c7c is described below

commit 24d7027c7c47238c03a8a187978a6db1a57bf3f8
Author: Henning Noeth <hn...@apache.org>
AuthorDate: Wed Oct 5 10:48:40 2022 +0200

    feat: rename to jakarta namespace
    
    Rename the namespace from javax.* to jakarta.*
    
    Issue: TOBAGO-2094
---
 tobago-core/src/main/faces-config/faces-config.xml         |  2 +-
 .../apache/myfaces/tobago/component/UINamingContainer.java |  2 +-
 .../myfaces/tobago/context/TobagoExceptionHandler.java     | 10 +++++-----
 .../myfaces/tobago/internal/behavior/DeltaStateHelper.java |  6 +++---
 .../myfaces/tobago/internal/behavior/EventBehavior.java    |  2 +-
 .../myfaces/tobago/internal/component/AbstractUILabel.java |  2 +-
 .../myfaces/tobago/internal/component/AbstractUIPage.java  |  2 +-
 .../renderkit/renderer/DecodingCommandRendererBase.java    |  2 +-
 .../tobago/internal/renderkit/renderer/PageRenderer.java   |  8 ++++----
 .../tobago/internal/renderkit/renderer/ReloadRenderer.java |  2 +-
 .../tobago/internal/renderkit/renderer/SheetRenderer.java  |  6 +++---
 .../internal/renderkit/renderer/SplitLayoutRenderer.java   |  2 +-
 .../internal/taglib/declaration/HasActionListener.java     |  2 +-
 .../tobago/internal/taglib/declaration/HasConverter.java   |  2 +-
 .../taglib/declaration/HasValueChangeListener.java         |  2 +-
 .../apache/myfaces/tobago/internal/util/RenderUtils.java   |  4 ++--
 .../org/apache/myfaces/tobago/renderkit/RendererBase.java  |  4 ++--
 .../java/org/apache/myfaces/tobago/util/AjaxUtils.java     |  2 +-
 .../org/apache/myfaces/tobago/util/ComponentUtils.java     |  2 +-
 tobago-example/pom.xml                                     | 12 ++++++------
 .../tobago-example-blank/src/main/webapp/WEB-INF/web.xml   |  2 +-
 tobago-example/tobago-example-demo/pom.xml                 | 12 ++++++------
 .../myfaces/tobago/example/demo/ExceptionController.java   |  2 +-
 .../org/apache/myfaces/tobago/example/demo/Version.java    |  6 +++---
 .../tobago-example-demo/src/main/webapp/WEB-INF/web.xml    | 14 +++++++-------
 tobago-theme/tobago-theme-standard/src/main/js/tobago.js   |  4 ++--
 .../tobago-theme-standard/src/main/js/tobago.js.map        |  2 +-
 .../tobago-theme-standard/src/main/ts/tobago-behavior.ts   |  4 ++--
 .../tobago-theme-standard/src/main/ts/tobago-page.ts       | 12 ++++++------
 .../tobago-theme-standard/src/main/ts/tobago-reload.ts     |  2 +-
 .../tobago-theme-standard/src/main/ts/tobago-sheet.ts      |  4 ++--
 .../tobago-theme-standard/src/main/ts/tobago-suggest.ts    |  2 +-
 .../tobago-theme-standard/src/main/ts/tobago-tree-node.ts  |  2 +-
 .../src/main/resources/META-INF/web-fragment.xml           |  2 +-
 34 files changed, 73 insertions(+), 73 deletions(-)

diff --git a/tobago-core/src/main/faces-config/faces-config.xml b/tobago-core/src/main/faces-config/faces-config.xml
index 8df4662396..c017ed151f 100644
--- a/tobago-core/src/main/faces-config/faces-config.xml
+++ b/tobago-core/src/main/faces-config/faces-config.xml
@@ -55,7 +55,7 @@
 
   <render-kit>
     <client-behavior-renderer>
-      <!--<client-behavior-renderer-type>javax.faces.behavior.Ajax</client-behavior-renderer-type>-->
+      <!--<client-behavior-renderer-type>jakarta.faces.behavior.Ajax</client-behavior-renderer-type>-->
       <client-behavior-renderer-type>org.apache.myfaces.tobago.behavior.Ajax</client-behavior-renderer-type>
       <client-behavior-renderer-class>org.apache.myfaces.tobago.internal.renderkit.renderer.TobagoClientBehaviorRenderer</client-behavior-renderer-class>
     </client-behavior-renderer>
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/component/UINamingContainer.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/component/UINamingContainer.java
index 63dcf15b6a..6db13cfb21 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/component/UINamingContainer.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/component/UINamingContainer.java
@@ -22,6 +22,6 @@ package org.apache.myfaces.tobago.component;
 public class UINamingContainer
     extends jakarta.faces.component.UINamingContainer {
 
-  public static final String COMPONENT_TYPE = "javax.faces.NamingContainer";
+  public static final String COMPONENT_TYPE = "jakarta.faces.NamingContainer";
 
 }
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/context/TobagoExceptionHandler.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/context/TobagoExceptionHandler.java
index 28631046da..db145cb24c 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/context/TobagoExceptionHandler.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/context/TobagoExceptionHandler.java
@@ -74,11 +74,11 @@ public class TobagoExceptionHandler extends ExceptionHandlerWrapper {
               final HttpServletResponse response =
                   (HttpServletResponse) facesContext.getExternalContext().getResponse();
 
-              request.setAttribute("javax.servlet.error.exception", exception);
-              request.setAttribute("javax.servlet.error.exception_type", exception.getClass());
-              request.setAttribute("javax.servlet.error.message", exception.getMessage());
-              request.setAttribute("javax.servlet.error.request_uri", request.getRequestURI());
-              request.setAttribute("javax.servlet.error.status_code", HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
+              request.setAttribute("jakarta.servlet.error.exception", exception);
+              request.setAttribute("jakarta.servlet.error.exception_type", exception.getClass());
+              request.setAttribute("jakarta.servlet.error.message", exception.getMessage());
+              request.setAttribute("jakarta.servlet.error.request_uri", request.getRequestURI());
+              request.setAttribute("jakarta.servlet.error.status_code", HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
 
               response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
 
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/behavior/DeltaStateHelper.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/behavior/DeltaStateHelper.java
index ce2158723b..7b9a460c34 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/behavior/DeltaStateHelper.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/behavior/DeltaStateHelper.java
@@ -79,9 +79,9 @@ import java.util.Map;
  * </p>
  * <ul>
  * <li> A new template is created (using
- * javax.faces.view.ViewDeclarationLanguage.buildView method)
+ * jakarta.faces.view.ViewDeclarationLanguage.buildView method)
  * and component.markInitialState is called from its related TagHandler classes
- * (see javax.faces.view.facelets.ComponentHandler ).
+ * (see jakarta.faces.view.facelets.ComponentHandler ).
  * When this method is executed, the component tree was populated from the values
  * set in the facelet abstract syntax tree (or in other words composition of
  * facelets templates). </li>
@@ -95,7 +95,7 @@ import java.util.Map;
  * <li> A new template is created and component.markInitialState is called from
  * its related TagHandler classes again. In this way, components like c:forEach
  * or c:if, that add or remove components could notify about this and handle
- * them properly (see javax.faces.view.StateManagementStrategy). Note that a
+ * them properly (see jakarta.faces.view.StateManagementStrategy). Note that a
  * component restored using this method is no different as the same component
  * at the first request at the same time. </li>
  * <li> A call for restoreState is done, passing the delta as object value. If no
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/behavior/EventBehavior.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/behavior/EventBehavior.java
index c6185669c3..20e4171df7 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/behavior/EventBehavior.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/behavior/EventBehavior.java
@@ -45,7 +45,7 @@ public class EventBehavior extends ClientBehaviorBase {
    * not needed anymore but enforced by the spec
    * theoretically a
    *
-   * FacesBehavior(value = "javax.faces.behavior.Ajax")
+   * FacesBehavior(value = "jakarta.faces.behavior.Ajax")
    * could do it
    */
   public static final String BEHAVIOR_ID = "org.apache.myfaces.tobago.behavior.Event";
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUILabel.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUILabel.java
index 79de804b32..f1cfea32a7 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUILabel.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUILabel.java
@@ -32,7 +32,7 @@ public abstract class AbstractUILabel
   /*
    * Need to set the name to 'forComponent' which comes from UILabel.PropertyKeys.forComponent.
    * TODO a better way would be to improve the UILabel.PropertyKeys, so an exact string could be specified.
-   * As an example, look at: javax.faces.component.UIMessages
+   * As an example, look at: jakarta.faces.component.UIMessages
    */
   @Override
   public void setValueExpression(String name, ValueExpression expression) {
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUIPage.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUIPage.java
index dd0db9c179..c58842af5e 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUIPage.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUIPage.java
@@ -85,7 +85,7 @@ public abstract class AbstractUIPage extends AbstractUIFormBase implements Clien
     // reset old submitted state
     setSubmitted(false);
 
-    String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("javax.faces.source");
+    String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("jakarta.faces.source");
     UIComponent command = null;
     if (sourceId != null) {
       if (LOG.isDebugEnabled()) {
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/DecodingCommandRendererBase.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/DecodingCommandRendererBase.java
index 7013ec4f55..53f020ddc9 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/DecodingCommandRendererBase.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/DecodingCommandRendererBase.java
@@ -41,7 +41,7 @@ public abstract class DecodingCommandRendererBase<T extends UIComponent> extends
         && ((AbstractUICommandBase) component).isDisabled()) {
       return;
     }
-    final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("javax.faces.source");
+    final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("jakarta.faces.source");
     final String clientId = component.getClientId(facesContext);
     if (LOG.isDebugEnabled()) {
       LOG.debug("sourceId = '{}", sourceId);
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/PageRenderer.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/PageRenderer.java
index 5cf5b88170..d0ed94544d 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/PageRenderer.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/PageRenderer.java
@@ -69,7 +69,7 @@ import java.util.Locale;
 import java.util.Map;
 
 // using faces.js from a specific MyFaces version instead, to avoid old bugs
-//@ResourceDependency(name="faces.js", library="javax.faces", target="head")
+//@ResourceDependency(name="faces.js", library="jakarta.faces", target="head")
 public class PageRenderer<T extends AbstractUIPage> extends RendererBase<T> {
 
   private static final Logger LOG = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
@@ -240,8 +240,8 @@ public class PageRenderer<T extends AbstractUIPage> extends RendererBase<T> {
 
     writer.startElement(HtmlElements.INPUT);
     writer.writeAttribute(HtmlAttributes.TYPE, HtmlInputTypes.HIDDEN);
-    writer.writeNameAttribute("javax.faces.source");
-    writer.writeIdAttribute("javax.faces.source");
+    writer.writeNameAttribute("jakarta.faces.source");
+    writer.writeIdAttribute("jakarta.faces.source");
     writer.writeAttribute(HtmlAttributes.DISABLED, true);
     writer.endElement(HtmlElements.INPUT);
 
@@ -366,7 +366,7 @@ public class PageRenderer<T extends AbstractUIPage> extends RendererBase<T> {
         } else {
           if (uiComponent instanceof UIOutput) {
             final Map<String, Object> attributes = uiComponent.getAttributes();
-            if ("javax.faces".equals(attributes.get("library"))
+            if ("jakarta.faces".equals(attributes.get("library"))
               && "faces.js".equals(attributes.get("name"))) {
               // workaround for WebSphere
               // We don't need faces.js from the JSF impl, because Tobago comes with its own faces.js
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/ReloadRenderer.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/ReloadRenderer.java
index 66f5a7e96a..84cdba2c18 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/ReloadRenderer.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/ReloadRenderer.java
@@ -40,7 +40,7 @@ public class ReloadRenderer<T extends AbstractUIReload> extends RendererBase<T>
   @Override
   public void decodeInternal(final FacesContext facesContext, final T component) {
 
-    final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("javax.faces.source");
+    final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("jakarta.faces.source");
     final String clientId = component.getClientId(facesContext);
     if (clientId.equals(sourceId)) {
       if (LOG.isDebugEnabled()) {
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/SplitLayoutRenderer.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/SplitLayoutRenderer.java
index 0c58990443..40bfe5a716 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/SplitLayoutRenderer.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/SplitLayoutRenderer.java
@@ -53,7 +53,7 @@ public class SplitLayoutRenderer<T extends AbstractUISplitLayout> extends Render
 
   @Override
   public void decodeInternal(final FacesContext facesContext, final T component) {
-    final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("javax.faces.source");
+    final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("jakarta.faces.source");
     final String clientId = component.getClientId() + SUFFIX_SIZES;
     if (clientId.equals(sourceId)) {
       // only decode and update layout at resize request
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasActionListener.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasActionListener.java
index 06ec1b2fe2..513aead34f 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasActionListener.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasActionListener.java
@@ -34,6 +34,6 @@ public interface HasActionListener {
   @UIComponentTagAttribute(
       type = {},
       expression = DynamicExpression.METHOD_EXPRESSION_REQUIRED,
-      methodSignature = "javax.faces.event.ActionEvent")
+      methodSignature = "jakarta.faces.event.ActionEvent")
   void setActionListener(String actionListener);
 }
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasConverter.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasConverter.java
index a68239a97b..a2248ca262 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasConverter.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasConverter.java
@@ -35,7 +35,7 @@ public interface HasConverter {
    */
   @TagAttribute
   @UIComponentTagAttribute(
-      type = "javax.faces.convert.Converter",
+      type = "jakarta.faces.convert.Converter",
       expression = DynamicExpression.VALUE_EXPRESSION)
   void setConverter(String converter);
 }
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasValueChangeListener.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasValueChangeListener.java
index b48b22a53b..73e57d4436 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasValueChangeListener.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/HasValueChangeListener.java
@@ -34,6 +34,6 @@ public interface HasValueChangeListener {
   @UIComponentTagAttribute(
       type = {},
       expression = DynamicExpression.METHOD_EXPRESSION_REQUIRED,
-      methodSignature = "javax.faces.event.ValueChangeEvent")
+      methodSignature = "jakarta.faces.event.ValueChangeEvent")
   void setValueChangeListener(String valueChangeListener);
 }
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/util/RenderUtils.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/util/RenderUtils.java
index 271a96cf79..6ff08b3aff 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/util/RenderUtils.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/util/RenderUtils.java
@@ -398,11 +398,11 @@ public final class RenderUtils {
       final Map<String, List<ClientBehavior>> clientBehaviors = clientBehaviorHolder.getClientBehaviors();
       if (clientBehaviors != null && !clientBehaviors.isEmpty()) {
         final Map<String, String> paramMap = facesContext.getExternalContext().getRequestParameterMap();
-        final String behaviorEventName = paramMap.get("javax.faces.behavior.event");
+        final String behaviorEventName = paramMap.get("jakarta.faces.behavior.event");
         if (behaviorEventName != null) {
           final List<ClientBehavior> clientBehaviorList = clientBehaviors.get(behaviorEventName);
           if (clientBehaviorList != null && !clientBehaviorList.isEmpty()) {
-            final String clientId = paramMap.get("javax.faces.source");
+            final String clientId = paramMap.get("jakarta.faces.source");
             if (component.getClientId(facesContext).equals(clientId)) {
               for (final ClientBehavior clientBehavior : clientBehaviorList) {
                 clientBehavior.decode(facesContext, component);
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/RendererBase.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/RendererBase.java
index f38b13a5c6..53732e5bf8 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/RendererBase.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/RendererBase.java
@@ -364,11 +364,11 @@ public abstract class RendererBase<T extends UIComponent> extends Renderer {
       final Map<String, List<ClientBehavior>> clientBehaviors = clientBehaviorHolder.getClientBehaviors();
       if (clientBehaviors != null && !clientBehaviors.isEmpty()) {
         final Map<String, String> paramMap = facesContext.getExternalContext().getRequestParameterMap();
-        final String behaviorEventName = paramMap.get("javax.faces.behavior.event");
+        final String behaviorEventName = paramMap.get("jakarta.faces.behavior.event");
         if (behaviorEventName != null) {
           final List<ClientBehavior> clientBehaviorList = clientBehaviors.get(behaviorEventName);
           if (clientBehaviorList != null && !clientBehaviorList.isEmpty()) {
-            final String clientId = paramMap.get("javax.faces.source");
+            final String clientId = paramMap.get("jakarta.faces.source");
             if (component.getClientId(facesContext).equals(clientId)) {
               for (final ClientBehavior clientBehavior : clientBehaviorList) {
                 clientBehavior.decode(facesContext, component);
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/util/AjaxUtils.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/util/AjaxUtils.java
index e3a1138e92..caa90c3019 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/util/AjaxUtils.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/util/AjaxUtils.java
@@ -42,7 +42,7 @@ public class AjaxUtils {
       requestType = httpServletRequest.getHeader("Faces-Request");
     }
     return "partial/ajax".equalsIgnoreCase(requestType)
-        || "true".equalsIgnoreCase(request.getParameter("javax.faces.partial.ajax"));
+        || "true".equalsIgnoreCase(request.getParameter("jakarta.faces.partial.ajax"));
   }
 
   public static void addRenderIds(final String... renderIds) {
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/util/ComponentUtils.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/util/ComponentUtils.java
index d8483114dc..87e442635e 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/util/ComponentUtils.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/util/ComponentUtils.java
@@ -88,7 +88,7 @@ public final class ComponentUtils {
    *
    * @since 2.0.0
    */
-  public static final String DATA_ATTRIBUTES_KEY = "javax.faces.component.DATA_ATTRIBUTES_KEY";
+  public static final String DATA_ATTRIBUTES_KEY = "jakarta.faces.component.DATA_ATTRIBUTES_KEY";
 
   private ComponentUtils() {
   }
diff --git a/tobago-example/pom.xml b/tobago-example/pom.xml
index d0825361bc..300509b97f 100644
--- a/tobago-example/pom.xml
+++ b/tobago-example/pom.xml
@@ -82,9 +82,9 @@
           </configuration>
           <dependencies>
             <dependency> <!-- add JAXB to run the demo with Java 11 and higher -->
-              <groupId>javax.xml.bind</groupId>
-              <artifactId>jaxb-api</artifactId>
-              <version>2.3.1</version>
+              <groupId>jakarta.xml.bind</groupId>
+              <artifactId>jakarta.xml.bind-api</artifactId>
+              <version>3.0.1</version>
             </dependency>
           </dependencies>
         </plugin>
@@ -462,9 +462,9 @@
           <version>${project.version}</version>
         </dependency>
         <dependency> <!-- add JAXB to run the demo with Java 11 and higher -->
-          <groupId>javax.xml.bind</groupId>
-          <artifactId>jaxb-api</artifactId>
-          <version>2.3.1</version>
+          <groupId>jakarta.xml.bind</groupId>
+          <artifactId>jakarta.xml.bind-api</artifactId>
+          <version>3.0.1</version>
         </dependency>
       </dependencies>
     </profile>
diff --git a/tobago-example/tobago-example-blank/src/main/webapp/WEB-INF/web.xml b/tobago-example/tobago-example-blank/src/main/webapp/WEB-INF/web.xml
index 8212314203..d1ebb8b200 100644
--- a/tobago-example/tobago-example-blank/src/main/webapp/WEB-INF/web.xml
+++ b/tobago-example/tobago-example-blank/src/main/webapp/WEB-INF/web.xml
@@ -25,7 +25,7 @@
   <display-name>Blank Tobago Application</display-name>
 
   <context-param>
-    <param-name>javax.faces.PROJECT_STAGE</param-name>
+    <param-name>jakarta.faces.PROJECT_STAGE</param-name>
     <param-value>Development</param-value>
   </context-param>
 
diff --git a/tobago-example/tobago-example-demo/pom.xml b/tobago-example/tobago-example-demo/pom.xml
index a740fa8039..8ba6e93ec6 100644
--- a/tobago-example/tobago-example-demo/pom.xml
+++ b/tobago-example/tobago-example-demo/pom.xml
@@ -178,9 +178,9 @@
       <scope>test</scope>
     </dependency>
     <dependency>
-      <groupId>javax.persistence</groupId>
-      <artifactId>javax.persistence-api</artifactId>
-      <version>2.2</version>
+      <groupId>jakarta.persistence</groupId>
+      <artifactId>jakarta.persistence-api</artifactId>
+      <version>3.0.0</version>
       <scope>test</scope>
     </dependency>
     <dependency>
@@ -482,9 +482,9 @@
           <version>${project.version}</version>
         </dependency>
         <dependency> <!-- add JAXB to run the demo with Java 11 and higher -->
-          <groupId>javax.xml.bind</groupId>
-          <artifactId>jaxb-api</artifactId>
-          <version>2.3.1</version>
+          <groupId>jakarta.xml.bind</groupId>
+          <artifactId>jakarta.xml.bind-api</artifactId>
+          <version>3.0.1</version>
         </dependency>
       </dependencies>
     </profile>
diff --git a/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/ExceptionController.java b/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/ExceptionController.java
index 0f840e1219..63ac4bb702 100644
--- a/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/ExceptionController.java
+++ b/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/ExceptionController.java
@@ -32,7 +32,7 @@ public class ExceptionController implements Serializable {
 
   public String getStackTrace() {
     final Throwable exception = (Throwable) FacesContext.getCurrentInstance().getExternalContext()
-            .getRequestMap().get("javax.servlet.error.exception");
+            .getRequestMap().get("jakarta.servlet.error.exception");
     final StringWriter stringWriter = new StringWriter();
     final PrintWriter printWriter = new PrintWriter(stringWriter);
     if (exception != null) {
diff --git a/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/Version.java b/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/Version.java
index afab02a2fc..42cdd78416 100644
--- a/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/Version.java
+++ b/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/Version.java
@@ -28,9 +28,9 @@ import jakarta.inject.Named;
 @ApplicationScoped
 public class Version {
 
-  private static final boolean CDI10 = hasClass("javax.enterprise.context.Conversation");
-  private static final boolean CDI1112 = hasClass("javax.enterprise.context.Destroyed");
-  private static final boolean CDI20 = hasClass("javax.enterprise.context.BeforeDestroyed");
+  private static final boolean CDI10 = hasClass("jakarta.enterprise.context.Conversation");
+  private static final boolean CDI1112 = hasClass("jakarta.enterprise.context.Destroyed");
+  private static final boolean CDI20 = hasClass("jakarta.enterprise.context.BeforeDestroyed");
 
   private static boolean hasClass(String clazz) {
     try {
diff --git a/tobago-example/tobago-example-demo/src/main/webapp/WEB-INF/web.xml b/tobago-example/tobago-example-demo/src/main/webapp/WEB-INF/web.xml
index a00d929ce9..c6072f1727 100644
--- a/tobago-example/tobago-example-demo/src/main/webapp/WEB-INF/web.xml
+++ b/tobago-example/tobago-example-demo/src/main/webapp/WEB-INF/web.xml
@@ -25,7 +25,7 @@
   <display-name>Tobago Demo Application</display-name>
 
   <!-- for local development you can set a Maven profile with -Pdev to set the
-  javax.faces.PROJECT_STAGE to Development -->
+  jakarta.faces.PROJECT_STAGE to Development -->
 
   <context-param>
     <param-name>com.sun.faces.validateXml</param-name>
@@ -34,7 +34,7 @@
 
 <!-- enable for websockets -->
   <context-param>
-    <param-name>javax.faces.ENABLE_WEBSOCKET_ENDPOINT</param-name>
+    <param-name>jakarta.faces.ENABLE_WEBSOCKET_ENDPOINT</param-name>
     <param-value>true</param-value>
   </context-param>
 
@@ -45,22 +45,22 @@
   </context-param>
 
   <context-param>
-    <param-name>javax.faces.FACELETS_SKIP_COMMENTS</param-name>
+    <param-name>jakarta.faces.FACELETS_SKIP_COMMENTS</param-name>
     <param-value>true</param-value>
   </context-param>
 
   <context-param>
-    <param-name>javax.faces.FACELETS_VIEW_MAPPINGS</param-name>
+    <param-name>jakarta.faces.FACELETS_VIEW_MAPPINGS</param-name>
     <param-value>*.xhtml</param-value>
   </context-param>
 
   <context-param>
-    <param-name>javax.faces.INTERPRET_EMPTY_STRING_SUBMITTED_VALUES_AS_NULL</param-name>
+    <param-name>jakarta.faces.INTERPRET_EMPTY_STRING_SUBMITTED_VALUES_AS_NULL</param-name>
     <param-value>true</param-value>
   </context-param>
 
   <context-param>
-    <param-name>javax.faces.DATETIMECONVERTER_DEFAULT_TIMEZONE_IS_SYSTEM_TIMEZONE</param-name>
+    <param-name>jakarta.faces.DATETIMECONVERTER_DEFAULT_TIMEZONE_IS_SYSTEM_TIMEZONE</param-name>
     <param-value>true</param-value>
   </context-param>
 
@@ -75,7 +75,7 @@
   </context-param>
 
   <context-param>
-    <param-name>javax.faces.CLIENT_WINDOW_MODE</param-name>
+    <param-name>jakarta.faces.CLIENT_WINDOW_MODE</param-name>
     <param-value>url</param-value>
   </context-param>
 
diff --git a/tobago-theme/tobago-theme-standard/src/main/js/tobago.js b/tobago-theme/tobago-theme-standard/src/main/js/tobago.js
index 378c89cf74..c926103e1c 100644
--- a/tobago-theme/tobago-theme-standard/src/main/js/tobago.js
+++ b/tobago-theme/tobago-theme-standard/src/main/js/tobago.js
@@ -1,8 +1,8 @@
-!function(e){"function"==typeof define&&define.amd?define(e):e()}((function(){"use strict";class e extends HTMLElement{constructor(){super(),this.CssClass={SHOW:"show",COLLAPSE:"collapse",COLLAPSING:"collapsing"},this.toggleButton.addEventListener("click",this.toggleCollapse.bind(this))}connectedCallback(){this.expanded="true"===this.toggleButton.ariaExpanded}toggleCollapse(e){window.clearTimeout(this.timeout),this.expanded?(this.expanded=!1,this.navbarContent.style.height=`${this.navbar [...]
+!function(e){"function"==typeof define&&define.amd?define(e):e()}((function(){"use strict";class e extends HTMLElement{constructor(){super(),this.CssClass={SHOW:"show",COLLAPSE:"collapse",COLLAPSING:"collapsing"},this.toggleButton.addEventListener("click",this.toggleCollapse.bind(this))}connectedCallback(){this.expanded="true"===this.toggleButton.ariaExpanded}toggleCollapse(e){window.clearTimeout(this.timeout),this.expanded?(this.expanded=!1,this.navbarContent.style.height=`${this.navbar [...]
 /*!
     * Bootstrap v5.2.2 (https://getbootstrap.com/)
     * Copyright 2011-2022 The Bootstrap Authors (https://github.com/twbs/bootstrap/graphs/contributors)
     * Licensed under MIT (https://github.com/twbs/bootstrap/blob/main/LICENSE)
     */
-const Me="transitionend",Re=e=>{let t=e.getAttribute("data-bs-target");if(!t||"#"===t){let s=e.getAttribute("href");if(!s||!s.includes("#")&&!s.startsWith("."))return null;s.includes("#")&&!s.startsWith("#")&&(s=`#${s.split("#")[1]}`),t=s&&"#"!==s?s.trim():null}return t},je=e=>{const t=Re(e);return t&&document.querySelector(t)?t:null},He=e=>{const t=Re(e);return t?document.querySelector(t):null},qe=e=>{e.dispatchEvent(new Event(Me))},Be=e=>!(!e||"object"!=typeof e)&&(void 0!==e.jquery&&( [...]
+const Me="transitionend",Re=e=>{let t=e.getAttribute("data-bs-target");if(!t||"#"===t){let s=e.getAttribute("href");if(!s||!s.includes("#")&&!s.startsWith("."))return null;s.includes("#")&&!s.startsWith("#")&&(s=`#${s.split("#")[1]}`),t=s&&"#"!==s?s.trim():null}return t},je=e=>{const t=Re(e);return t&&document.querySelector(t)?t:null},He=e=>{const t=Re(e);return t?document.querySelector(t):null},qe=e=>{e.dispatchEvent(new Event(Me))},Be=e=>!(!e||"object"!=typeof e)&&(void 0!==e.jquery&&( [...]
 //# sourceMappingURL=tobago.js.map
diff --git a/tobago-theme/tobago-theme-standard/src/main/js/tobago.js.map b/tobago-theme/tobago-theme-standard/src/main/js/tobago.js.map
index c47bbe9fc9..2a8c294e74 100644
--- a/tobago-theme/tobago-theme-standard/src/main/js/tobago.js.map
+++ b/tobago-theme/tobago-theme-standard/src/main/js/tobago.js.map
@@ -1 +1 @@
-{"version":3,"file":"tobago.js","sources":["../ts/tobago-bar.ts","../../../../node_modules/@popperjs/core/lib/enums.js","../../../../node_modules/@popperjs/core/lib/dom-utils/getNodeName.js","../../../../node_modules/@popperjs/core/lib/dom-utils/getWindow.js","../../../../node_modules/@popperjs/core/lib/dom-utils/instanceOf.js","../../../../node_modules/@popperjs/core/lib/modifiers/applyStyles.js","../../../../node_modules/@popperjs/core/lib/utils/getBasePlacement.js","../../../../node_m [...]
\ No newline at end of file
+{"version":3,"file":"tobago.js","sources":["../ts/tobago-bar.ts","../../../../node_modules/@popperjs/core/lib/enums.js","../../../../node_modules/@popperjs/core/lib/dom-utils/getNodeName.js","../../../../node_modules/@popperjs/core/lib/dom-utils/getWindow.js","../../../../node_modules/@popperjs/core/lib/dom-utils/instanceOf.js","../../../../node_modules/@popperjs/core/lib/modifiers/applyStyles.js","../../../../node_modules/@popperjs/core/lib/utils/getBasePlacement.js","../../../../node_m [...]
\ No newline at end of file
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-behavior.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-behavior.ts
index 21a5fbf923..b2babfc23d 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-behavior.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-behavior.ts
@@ -88,7 +88,7 @@ class Behavior extends HTMLElement {
             this.actionElement,
             event,
             {
-              "javax.faces.behavior.event": this.event,
+              "jakarta.faces.behavior.event": this.event,
               execute: this.execute,
               render: this.render
             });
@@ -113,7 +113,7 @@ class Behavior extends HTMLElement {
       const actionId = this.fieldId != null ? this.fieldId : this.clientId;
       const form = page.form;
       const oldTarget = form.getAttribute("target");
-      const sourceHidden = document.getElementById("javax.faces.source") as HTMLInputElement;
+      const sourceHidden = document.getElementById("jakarta.faces.source") as HTMLInputElement;
       sourceHidden.disabled = false;
       sourceHidden.value = actionId;
       if (this.target != null) {
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-page.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-page.ts
index 80f920aabc..27802b8ae6 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-page.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-page.ts
@@ -187,12 +187,12 @@ document.addEventListener("tobago.init", (event: Event): void => {
 
 class JsfParameter {
 
-  static VIEW_STATE = "javax.faces.ViewState";
-  static CLIENT_WINDOW = "javax.faces.ClientWindow";
-  static VIEW_ROOT = "javax.faces.ViewRoot";
-  static VIEW_HEAD = "javax.faces.ViewHead";
-  static VIEW_BODY = "javax.faces.ViewBody";
-  static RESOURCE = "javax.faces.Resource";
+  static VIEW_STATE = "jakarta.faces.ViewState";
+  static CLIENT_WINDOW = "jakarta.faces.ClientWindow";
+  static VIEW_ROOT = "jakarta.faces.ViewRoot";
+  static VIEW_HEAD = "jakarta.faces.ViewHead";
+  static VIEW_BODY = "jakarta.faces.ViewBody";
+  static RESOURCE = "jakarta.faces.Resource";
 
   static isJsfId(id: string): boolean {
     switch (id) {
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-reload.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-reload.ts
index d5099a029a..269561f6a6 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-reload.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-reload.ts
@@ -48,7 +48,7 @@ class TobagoReload extends HTMLElement {
             reloadId,
             null,
             {
-              "javax.faces.behavior.event": "reload",
+              "jakarta.faces.behavior.event": "reload",
               execute: `${reloadId} ${componentId}`,
               render: `${reloadId} ${componentId}`
             });
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-sheet.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-sheet.ts
index 3ce48491ce..e30807c041 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-sheet.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-sheet.ts
@@ -461,7 +461,7 @@ Type: ${data.type}`);
         source.id,
         null,
         {
-          "javax.faces.behavior.event": "reload",
+          "jakarta.faces.behavior.event": "reload",
           execute: executeIds,
           render: renderIds,
           onevent: lazy ? this.lazyResponse.bind(this) : undefined,
@@ -679,7 +679,7 @@ Type: ${data.type}`);
           input.id,
           null,
           {
-            "javax.faces.behavior.event": "reload",
+            "jakarta.faces.behavior.event": "reload",
             execute: this.id,
             render: this.id
           });
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-suggest.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-suggest.ts
index 2a55b517f5..d08330110c 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-suggest.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-suggest.ts
@@ -61,7 +61,7 @@ export class Suggest {
             this.resolve = resolve;
             const suggestId = this.suggest.id;
             jsf.ajax.request(suggestId, null, {
-              "javax.faces.behavior.event": "suggest",
+              "jakarta.faces.behavior.event": "suggest",
               execute: suggestId,
               render: suggestId
             });
diff --git a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-tree-node.ts b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-tree-node.ts
index 2f2139ff7c..8c269420d6 100644
--- a/tobago-theme/tobago-theme-standard/src/main/ts/tobago-tree-node.ts
+++ b/tobago-theme/tobago-theme-standard/src/main/ts/tobago-tree-node.ts
@@ -79,7 +79,7 @@ export class TreeNode extends HTMLElement {
         this.id,
         event,
         {
-          "javax.faces.behavior.event": "change",
+          "jakarta.faces.behavior.event": "change",
           execute: this.tree.id,
           render: renderTree ? this.tree.id : null
         });
diff --git a/tobago-tool/tobago-config-dev/src/main/resources/META-INF/web-fragment.xml b/tobago-tool/tobago-config-dev/src/main/resources/META-INF/web-fragment.xml
index 79c4da8851..083c32201c 100644
--- a/tobago-tool/tobago-config-dev/src/main/resources/META-INF/web-fragment.xml
+++ b/tobago-tool/tobago-config-dev/src/main/resources/META-INF/web-fragment.xml
@@ -26,7 +26,7 @@
   <name>tobago_config_dev</name>
 
   <context-param>
-    <param-name>javax.faces.PROJECT_STAGE</param-name>
+    <param-name>jakarta.faces.PROJECT_STAGE</param-name>
     <param-value>Development</param-value>
   </context-param>
diff --git a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/SheetRenderer.java b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/SheetRenderer.java
index 1218dc8687..9a462a678e 100644
--- a/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/SheetRenderer.java
+++ b/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/renderkit/renderer/SheetRenderer.java
@@ -144,7 +144,7 @@ public class SheetRenderer<T extends AbstractUISheet> extends RendererBase<T> {
 
     decodeSheetAction(facesContext, component);
     decodeColumnAction(facesContext, columns);
 /* this will be done by the javax.faces.component.UIData.processDecodes() because these are facets.
     for (UIComponent facet : sheet.getFacets().values()) {
       facet.decode(facesContext);
     }
@@ -155,7 +155,7 @@ public class SheetRenderer<T extends AbstractUISheet> extends RendererBase<T> {
     for (final AbstractUIColumnBase column : columns) {
       final boolean sortable = ComponentUtils.getBooleanAttribute(column, Attributes.sortable);
       if (sortable) {
-        final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("javax.faces.source");
+        final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("jakarta.faces.source");
         final String columnId = column.getClientId(facesContext);
         final String sorterId = columnId + "_" + AbstractUISheet.SORTER_ID;
 
@@ -169,7 +169,7 @@ public class SheetRenderer<T extends AbstractUISheet> extends RendererBase<T> {
 
 
   private void decodeSheetAction(final FacesContext facesContext, final AbstractUISheet component) {
-    final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("javax.faces.source");
+    final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("jakarta.faces.source");
 
     final String clientId = component.getClientId(facesContext);
     if (LOG.isDebugEnabled()) {
@@ -144,7 +144,7 @@ public class SheetRenderer<T extends AbstractUISheet> extends RendererBase<T> {
     decodeSheetAction(facesContext, component);
     decodeColumnAction(facesContext, columns);
-/* this will be done by the javax.faces.component.UIData.processDecodes() because these are facets.
+/* this will be done by the jakarta.faces.component.UIData.processDecodes() because these are facets.
     for (UIComponent facet : sheet.getFacets().values()) {
       facet.decode(facesContext);